QueryHistoryRequest

Struct QueryHistoryRequest 

pub struct QueryHistoryRequest {
    pub collection_period_count: Option<i32>,
    pub form_factor: Option<String>,
    pub metrics: Option<Vec<String>>,
    pub origin: Option<String>,
    pub url: Option<String>,
}
Request payload sent by a physical web client. This request includes all necessary context to load a particular user experience history record.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

collection_period_count: Option<i32>

The number of collection periods to return. If not specified, the default is 25. If present, must be in the range [1, 40].

form_factor: Option<String>

The form factor is a query dimension that specifies the device class that the record’s data should belong to. Note: If no form factor is specified, then a special record with aggregated data over all form factors will be returned.

metrics: Option<Vec<String>>

The metrics that should be included in the response. If none are specified then any metrics found will be returned. Allowed values: [“first_contentful_paint”, “first_input_delay”, “largest_contentful_paint”, “cumulative_layout_shift”, “experimental_time_to_first_byte”, “experimental_interaction_to_next_paint”]

origin: Option<String>

The url pattern “origin” refers to a url pattern that is the origin of a website. Examples: “https://example.com”, “https://cloud.google.com”

url: Option<String>

The url pattern “url” refers to a url pattern that is any arbitrary url. Examples: “https://example.com/”, “https://cloud.google.com/why-google-cloud/”