pub struct QueryRequest {
pub effective_connection_type: Option<String>,
pub form_factor: Option<String>,
pub metrics: Option<Vec<String>>,
pub origin: Option<String>,
pub url: Option<String>,
}Expand description
Request payload sent by a physical web client. This request includes all necessary context to load a particular user experience record.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- query record records (request)
Fields
effective_connection_type: Option<String>The effective connection type is a query dimension that specifies the effective network class that the record’s data should belong to. This field uses the values [“offline”, “slow-2G”, “2G”, “3G”, “4G”] as specified in: https://wicg.github.io/netinfo/#effective-connection-types Note: If no effective connection type is specified, then a special record with aggregated data over all effective connection types will be returned.
form_factor: Option<String>The form factor is a query dimension that specifies the device class that the record’s data should belong to. Note: If no form factor is specified, then a special record with aggregated data over all form factors will be returned.
metrics: Option<Vec<String>>The metrics that should be included in the response. If none are specified then any metrics found will be returned. Allowed values: [“first_contentful_paint”, “first_input_delay”, “largest_contentful_paint”, “cumulative_layout_shift”, “experimental_time_to_first_byte”, “experimental_interaction_to_next_paint”]
origin: Option<String>The url pattern “origin” refers to a url pattern that is the origin of a website. Examples: “https://example.com”, “https://cloud.google.com”
url: Option<String>The url pattern “url” refers to a url pattern that is any arbitrary url. Examples: “https://example.com/”, “https://cloud.google.com/why-google-cloud/”